@@ -1,4 +1,4 @@
-from rest_framework.exceptions import ValidationError
+from rest_framework import serializers
 
 from ..conf import conf
 
@@ -18,7 +18,7 @@ def get_error(error_message):
     return ERROR
 
 
-class RestApiException(ValidationError):
+class RestApiException(serializers.ValidationError):
     status_code = 400
     default_detail = ""
 
@@ -30,5 +30,6 @@ class SMSWaitException(RestApiException):
 class UserAlreadyExistException(RestApiException):
     default_detail = get_error(conf.SMS_USER_ALREADY_EXIST)
 
+
 class SMSCodeNotFoundException(RestApiException):
-    default_detail = get_error(conf.SMS_CODE_NOT_FOUND)
\ No newline at end of file
+    default_detail = get_error(conf.SMS_CODE_NOT_FOUND)
